==> ads_flutter-1.0.5.tar.gz: lib/src/ads_banner.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'ads_banner_controller.dart';
import 'ads_events.dart';

class AdsBanner extends StatefulWidget {
  final String adUnitId;
  final bool showBuyThisAd;
  final bool autoHideUnavailableAd;
  //final AdsBannerSize adSize;
  final void Function(AdsAdEvent, Map<String, dynamic>?)? listener;
  final void Function(AdsBannerController)? onBannerCreated;
  final bool nonPersonalizedAds;

  AdsBanner({
    Key? key,
    required this.adUnitId,
    this.showBuyThisAd = true,
    this.autoHideUnavailableAd = false,
    //required this.adSize,
    this.listener,
    this.onBannerCreated,
    this.nonPersonalizedAds = false,
  }) : super(key: key);

  @override
  _AdmobBannerState createState() => _AdmobBannerState();
}

class _AdmobBannerState extends State<AdsBanner> {
  final UniqueKey _key = UniqueKey();
  late AdsBannerController _controller;
  Future<Size>? adSize;

  @override
  void initState() {
    super.initState();

    /* if (!widget.adSize.hasFixedSize) {
      adSize = Ads.bannerSize(widget.adSize);
    } else {
      adSize = Future.value(Size(
        widget.adSize.width.toDouble(),
        widget.adSize.height.toDouble(),
      ));
    } */
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<Size>(
      future: adSize,
      builder: (context, snapshot) {
        final adSize = snapshot.data;
        if (adSize == null) {
          return SizedBox.shrink();
        }

        if (defaultTargetPlatform == TargetPlatform.android) {
          return SizedBox.fromSize(
            size: adSize,
            child: AndroidView(
              key: _key,
              viewType: 'admob_flutter/banner',
              creationParams: bannerCreationParams,
              creationParamsCodec: const StandardMessageCodec(),
              onPlatformViewCreated: _onPlatformViewCreated,
            ),
          );
        } else if (defaultTargetPlatform == TargetPlatform.iOS) {
          return SizedBox.fromSize(
            size: adSize,
            child: UiKitView(
              key: _key,
              viewType: 'admob_flutter/banner',
              creationParams: bannerCreationParams,
              creationParamsCodec: const StandardMessageCodec(),
              onPlatformViewCreated: _onPlatformViewCreated,
            ),
          );
        }

        return Text(
            '$defaultTargetPlatform is not yet supported by the plugin');
      },
    );
  }

  void _onPlatformViewCreated(int id) {
    _controller = AdsBannerController(id, widget.listener);

    if (widget.onBannerCreated != null) {
      widget.onBannerCreated!(_controller);
    }
  }

  Map<String, dynamic> get bannerCreationParams => <String, dynamic>{
        'adUnitId': widget.adUnitId,
        'showBuyThisAd': widget.showBuyThisAd,
        'autoHideUnavailableAd': widget.autoHideUnavailableAd,
        //'adSize': widget.adSize.toMap,
        'nonPersonalizedAds': widget.nonPersonalizedAds,
      };
}

==> ads_flutter-1.0.7.tar.gz: lib/src/ads_banner.dart <==
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'ads.dart';
import 'ads_banner_controller.dart';
import 'ads_banner_size.dart';
import 'ads_events.dart';

class AdsFlutterBanner extends StatefulWidget {
  final String adUnitId;
  final AdsFlutterBannerSize adSize;
  final void Function(AdsFlutterAdEvent, Map<String, dynamic>?)? listener;
  final void Function(AdsFlutterBannerController)? onBannerCreated;
  final bool nonPersonalizedAds;

  AdsFlutterBanner({
    Key? key,
    required this.adUnitId,
    required this.adSize,
    this.listener,
    this.onBannerCreated,
    this.nonPersonalizedAds = false,
  }) : super(key: key);

  static String get testAdUnitId {
    if (Platform.isAndroid) {
      return 'ca-app-pub-3940256099942544/6300978111';
    } else if (Platform.isIOS) {
      return 'ca-app-pub-3940256099942544/2934735716';
    } else {
      throw UnsupportedError('Unsupported platform');
    }
  }

  @override
  _AdsFlutterBannerState createState() => _AdsFlutterBannerState();
}

class _AdsFlutterBannerState extends State<AdsFlutterBanner> {
  final UniqueKey _key = UniqueKey();
  late AdsFlutterBannerController _controller;
  Future<Size>? adSize;

  @override
  void initState() {
    super.initState();

    if (!widget.adSize.hasFixedSize) {
      adSize = AdsFlutter.bannerSize(widget.adSize);
    } else {
      adSize = Future.value(Size(
        widget.adSize.width.toDouble(),
        widget.adSize.height.toDouble(),
      ));
    }
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<Size>(
      future: adSize,
      builder: (context, snapshot) {
        final adSize = snapshot.data;
        if (adSize == null) {
          return SizedBox.shrink();
        }

        if (defaultTargetPlatform == TargetPlatform.android) {
          return SizedBox.fromSize(
            size: adSize,
            child: AndroidView(
              key: _key,
              viewType: 'admob_flutter/banner',
              creationParams: bannerCreationParams,
              creationParamsCodec: const StandardMessageCodec(),
              onPlatformViewCreated: _onPlatformViewCreated,
            ),
          );
        } else if (defaultTargetPlatform == TargetPlatform.iOS) {
          return SizedBox.fromSize(
            size: adSize,
            child: UiKitView(
              key: _key,
              viewType: 'admob_flutter/banner',
              creationParams: bannerCreationParams,
              creationParamsCodec: const StandardMessageCodec(),
              onPlatformViewCreated: _onPlatformViewCreated,
            ),
          );
        }

        return Text('$defaultTargetPlatform is not yet supported by the plugin');
      },
    );
  }

  void _onPlatformViewCreated(int id) {
    _controller = AdsFlutterBannerController(id, widget.listener);

    if (widget.onBannerCreated != null) {
      widget.onBannerCreated!(_controller);
    }
  }

  Map<String, dynamic> get bannerCreationParams => <String, dynamic>{
    'adUnitId': widget.adUnitId,
    'adSize': widget.adSize.toMap,
    'nonPersonalizedAds': widget.nonPersonalizedAds,
  };
}
